********************************************************************************
// Analysis of 1960-2010 IPSR well-being dataset
********************************************************************************

* set working directory:
cd ".../Replication files/"

use "ipsr_wellbeing1960-2010.dta", clear

xtset ccode period
est clear 


********************************************************************************
// Article
********************************************************************************

** TABLE 1

* W:1
eststo: xtreg pW pD pSP pSC if lpW != . & psample, fe cl(ccode)

* W:2
eststo: xtreg pW i.year lpW pD pSP pSC if psample, fe cl(ccode)
nlcom (_b[pD]) / (1-_b[lpW])
nlcom (_b[pSP]) / (1-_b[lpW])
nlcom (_b[pSC]) / (1-_b[lpW])

* W:3 
eststo: xtreg pW i.year lpW pD pSP pAC pEC if psample, fe cl(ccode)

* W:4
eststo: xtreg pW i.year lpW pD lpD pSP lpSP pSC lpSC if psample, fe cl(ccode)
nlcom (_b[pD] +_b[lpD]) / (1-_b[lpW])
nlcom (_b[pSP] +_b[lpSP]) / (1-_b[lpW])
nlcom (_b[pSC] +_b[lpSC]) / (1-_b[lpW])

* W:5
eststo: xtreg pW i.year lpW pD pSP pSC z_wdi_trade z_wdi_gdpagr z_wdi_popurb , fe cl(ccode)
nlcom (_b[pD]) / (1-_b[lpW])
nlcom (_b[pSP]) / (1-_b[lpW])
nlcom (_b[pSC]) / (1-_b[lpW])

* W:6
eststo: xtreg pW i.year lpW pD pSP pSC c.pD#c.pSP c.pD#c.pSC c.pSP#c.pSC, fe cl(ccode)
nlcom (_b[pD]) / (1-_b[lpW])
nlcom (_b[pSP]) / (1-_b[lpW])
nlcom (_b[pSC]) / (1-_b[lpW])

esttab, se(3) ar2 nogaps b(3) label star(* 0.10 ** 0.05 *** 0.01) nomtitles drop(*year)


** TABLE 2

xtreg pW i.year lpW pD pSP pSC c.pD#c.pSP c.pD#c.pSC c.pSP#c.pSC, fe cl(ccode)
sum pD if psample & l.pW != ., detail
local lowpD = r(p25)
local highpD = r(p75)
margins, dydx(pSP) at(pD =(`lowpD' `highpD'))
margins, dydx(pSC) at(pD =(`lowpD' `highpD'))

sum pSP if psample & l.pW != ., detail
local lowpSP = r(p25)
local highpSP = r(p75)
margins, dydx(pD) at(pSP =(`lowpSP' `highpSP'))
margins, dydx(pSC) at(pSP =(`lowpSP' `highpSP'))

sum pSC if psample & l.pW != ., detail
local lowpSC = r(p25)
local highpSC = r(p75)
margins, dydx(pD) at(pSC =(`lowpSC' `highpSC'))
margins, dydx(pSP) at(pSC =(`lowpSC' `highpSC'))


** TABLE 3 (+ TABLE AIV:2 in ONLINE APPENDIX IV)
est clear

* SP:1
eststo: xtreg pSP i.year l.pSP l(0/1).(pW pD pSC), fe cl(ccode)
nlcom (_b[pD] + _b[l.pD]) / (1-_b[l.pSP])
nlcom (_b[pSC] + _b[l.pSC]) / (1-_b[l.pSP])
nlcom (_b[pW] + _b[l.pW]) / (1-_b[l.pSP])

* SP:2
eststo: xtreg pSP i.year l.pSP l(0/1).(pW pD pEC pAC), fe cl(ccode)
nlcom (_b[pD] + _b[l.pD]) / (1-_b[l.pSP])
nlcom (_b[pEC] + _b[l.pEC]) / (1-_b[l.pSP])
nlcom (_b[pAC] + _b[l.pAC]) / (1-_b[l.pSP])
nlcom (_b[pW] + _b[l.pW]) / (1-_b[l.pSP])

* SC
eststo: xtreg pSC i.year l.pSC l(0/1).(pW pD pSP), fe cl(ccode)
nlcom (_b[pD] + _b[l.pD]) / (1-_b[l.pSC])
nlcom (_b[pSP] + _b[l.pSP]) / (1-_b[l.pSC])
nlcom (_b[pW] + _b[l.pW]) / (1-_b[l.pSC])

* D
eststo: xtreg pD i.year l.pD l(0/1).(pW pSP pSC), fe cl(ccode)
nlcom (_b[pSP] + _b[l.pSP]) / (1-_b[l.pD])
nlcom (_b[pSC] + _b[l.pSC]) / (1-_b[l.pD])
nlcom (_b[pW] + _b[l.pW]) / (1-_b[l.pD])

esttab, se(3) ar2 nogaps b(3) label star(* 0.10 ** 0.05 *** 0.01) nomtitles drop(*year)


********************************************************************************
// Online Appendix II
********************************************************************************

** TABLE AII:3
sum pW polyarchy socialprotection statecapacity pAC tax_logged tax_linear wdi_trade wdi_gdpagr wdi_popurb if e(sample)

** TABLE AII:4
corr pW polyarchy socialprotection statecapacity pAC tax_logged tax_linear wdi_trade wdi_gdpagr wdi_popurb if e(sample)


********************************************************************************
// Online Appendix III
********************************************************************************

** TABLE AIII:1
est clear

* AIII-W:1
eststo: xtreg pW i.year lpW pSP pD pSC c.lpW#c.pSP c.lpW#c.pD c.lpW#c.pSC, fe cl(ccode)
esttab, se(3) ar2 nogaps b(3) label star(* 0.10 ** 0.05 *** 0.01) nomtitles drop(*year)

sum lpW if psample, detail

margins, dydx(pD) at(lpW = ( -2(1)2))
marginsplot, yscale(alt) yscale(alt axis(1) range(-0.15,0.15)) recast(line) ciopts(recast(rline) lp(dash)) yline(0) addplot(hist lpW if psample, percent yaxis(2) yscale(alt axis(2) range(0,20)) xscale(range(-2,2)) ylabel(0(10)20, axis(2)) title("Democracy")  ytitle("", axis(2)) ylabel(-0.15(0.05)0.15, axis(1))) legend(off) xtitle("Lagged human development (W)") ytitle("") title("") name(d, replace)
margins, dydx(pSP) at(lpW = ( -2(1)2))
marginsplot, yscale(alt) yscale(alt axis(1) range(-0.15,0.15)) recast(line) ciopts(recast(rline) lp(dash)) yline(0) addplot(hist lpW if psample, percent yaxis(2) yscale(alt axis(2) range(0,20)) xscale(range(-2,2)) ylabel(0(10)20, axis(2)) title("Social protection") ytitle("", axis(2)) ylabel(-0.15(0.05)0.15, axis(1))) legend(off) xtitle("Lagged human development (W)") ytitle("") title("") name(sp, replace)
margins, dydx(pSC) at(lpW = ( -2(1)2))
marginsplot, yscale(alt) yscale(alt axis(1) range(-0.15,0.15)) recast(line) ciopts(recast(rline) lp(dash)) yline(0) addplot(hist lpW if psample, percent yaxis(2) yscale(alt axis(2) range(0,20)) xscale(range(-2,2)) ylabel(0(10)20, axis(2)) title("State capacity") ytitle("", axis(2)) ylabel(-0.15(0.05)0.15, axis(1))) legend(off) xtitle("Lagged human development (W)") ytitle("") title("") name(sc, replace)
gr combine d sp sc, col(3) l1title("Marginal effect on well-being") r1title("Distribution of observations (%)") altshrink ysize(2.25) xsize(7) iscale(*1.8)

* AIII-W:2
tab period, gen(pdum)

eststo: xtlsdvc pW pdum* pSP pD pSC if psample , initial(ab) vcov(500)
nlcom (_b[pD]) / (1-_b[l.pW])
nlcom (_b[pSP]) / (1-_b[l.pW])
nlcom (_b[pSC]) / (1-_b[l.pW])

* AIII-W:3
eststo: xtdpdqml pW pdum* pSP pD pSC if psample, vce(robust)
nlcom (_b[pD]) / (1-_b[l.pW])
nlcom (_b[pSP]) / (1-_b[l.pW])
nlcom (_b[pSC]) / (1-_b[l.pW])


* AIII-W:4
eststo: rreg pW l(1).pW pSP  pD  pSC i.ccode i.year if psample
nlcom (_b[pD]) / (1-_b[l.pW])
nlcom (_b[pSP]) / (1-_b[l.pW])
nlcom (_b[pSC]) / (1-_b[l.pW])

* AIII-W:5
eststo: xtreg pW i.year l.pW pSP pD pSC i.year#i.gdpq if psample, fe cl(ccode)
nlcom (_b[pD]) / (1-_b[l.pW])
nlcom (_b[pSP]) / (1-_b[l.pW])
nlcom (_b[pSC]) / (1-_b[l.pW])

* AIII-W:6
* (Instructions for Amelia II procedure are available upon request.)

esttab, se(3) ar2 nogaps b(3) label star(* 0.10 ** 0.05 *** 0.01) nomtitles drop(*year)


********************************************************************************
// Online Appendix IV
********************************************************************************

** TABLE AIV:1
est clear
local controls z_wdi_trade z_wdi_gdpagr z_wdi_popurb

eststo: xtreg pSP i.year l.pSP l(0).(pW pD pSC `controls') if psample , fe cl(ccode)
eststo: xtreg pSP i.year l.pSP l(0).(pW pD pEC pAC `controls')  if psample , fe cl(ccode)
eststo: xtreg pSC i.year l.pSC l(0).(pW pD pSP `controls') if psample , fe cl(ccode)
eststo: xtreg pD i.year l.pD l(0).(pW pSP pSC `controls') if psample , fe cl(ccode)

esttab, se(3) ar2 nogaps b(3) label star(* 0.10 ** 0.05 *** 0.01) nomtitles drop(*year)

** TABLE AIV:2
* (See TABLE 3 above.)



